@@ -1,9 +1,16 @@
-from django.contrib import admin
+import json
+from pprint import pprint
+
+import requests
+from django.contrib import admin, messages
+from django.core.validators import EMPTY_VALUES
 from django.db.models import F
 from django.db.models.functions import Coalesce
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
+from invoicing import settings as invoicing_settings
+from invoicing.managers import get_accounting_software_manager
 from invoicing.models import Invoice, Item
 
 
@@ -40,12 +47,14 @@ class OverdueFilter(admin.SimpleListFilter):
 @admin.register(Invoice)
 class InvoiceAdmin(admin.ModelAdmin):
     date_hierarchy = 'date_issue'
+    ordering = ['-date_issue', '-sequence']
+    actions = ['send_to_accounting_software']
     list_display = ['pk', 'type', 'number', 'status',
                     'supplier_info', 'customer_info',
                     'annotated_subtotal', 'vat', 'total',
                     'currency', 'date_issue', 'payment_term_days', 'is_overdue_boolean', 'is_paid']
     list_editable = ['status']
-    list_filter = ['type', 'status', 'payment_method', OverdueFilter, 'language', 'currency']
+    list_filter = ['type', 'status', 'payment_method', 'delivery_method', OverdueFilter, 'language', 'currency']
     search_fields = ['number', 'subtitle', 'note', 'supplier_name', 'customer_name', 'shipping_name']
     inlines = (ItemInline, )
     autocomplete_fields = ('related_invoices',)
@@ -64,9 +73,9 @@ class InvoiceAdmin(admin.ModelAdmin):
         }),
         (_(u'Payment details'), {
             'fields': (
-                'currency', 'credit',
-                #'already_paid',
-                'payment_method', 'constant_symbol', 'variable_symbol', 'specific_symbol', 'reference',
+                'currency', 'credit', #'already_paid',
+                ('payment_method', 'delivery_method'),
+                ('constant_symbol', 'variable_symbol', 'specific_symbol', 'reference'),
                 'bank_name', 'bank_country', 'bank_city', 'bank_street', 'bank_zip', 'bank_iban', 'bank_swift_bic'
             )
         }),
@@ -118,3 +127,31 @@ class InvoiceAdmin(admin.ModelAdmin):
         return invoice.status == Invoice.STATUS.PAID
     is_paid.boolean = True
     is_paid.short_description = _(u'is paid')
+
+    def send_to_accounting_software(self, request, queryset):
+        if invoicing_settings.ACCOUNTING_SOFTWARE in EMPTY_VALUES:
+            messages.error(request, _('Missing specification of accounting software'))
+            return
+
+        try:
+            manager = get_accounting_software_manager()
+            result = manager.send_to_accounting_software(queryset)
+
+            if isinstance(result, str):
+                messages.success(request, result)
+            elif isinstance(result, list):
+                success = 0
+
+                for r in result:
+                    if r['status_code'] == 200:
+                        success += 1
+                    else:
+                        messages.error(request, f"[{r['invoice']}]: {r['status_code']} ({r['reason']})")
+
+                if success > 0:
+                    messages.success(request, _('%d invoices sent to accounting software') % success)
+
+        except Exception as e:
+            messages.error(request, e)
+
+    send_to_accounting_software.short_description = _('Send to accounting software')
