@@ -13,7 +13,7 @@ from model_utils.fields import MonitorField
 from django.conf import settings
 from django.core.validators import EMPTY_VALUES, MaxValueValidator, MinValueValidator
 from django.db import models, transaction
-from django.db.models import Max
+from django.db.models import Max, Sum
 
 try:
     # Django 3.1
@@ -260,18 +260,20 @@ class Invoice(models.Model):
         return formatter(self, number_format)
 
     def get_tax_rate(self):
+        customer_country_code = self.customer_country.code if self.customer_country else None
+        supplier_country_code = self.supplier_country.code if self.supplier_country else None
+
         if self.taxation_policy:
             # There is taxation policy -> get tax rate
-            customer_country_code = self.customer_country.code if self.customer_country else None
-            supplier_country_code = self.supplier_country.code if self.supplier_country else None
             return self.taxation_policy.get_tax_rate(self.customer_vat_id, customer_country_code, supplier_country_code)
         else:
             # If there is not any special taxation policy, set default tax rate
-            return TaxationPolicy.get_default_tax()
+            return TaxationPolicy.get_default_tax(supplier_country_code)
 
     @property
     def taxation_policy(self):
         taxation_policy = getattr(settings, 'INVOICING_TAXATION_POLICY', None)
+
         if taxation_policy is not None:
             return import_name(taxation_policy)
 
@@ -296,6 +298,10 @@ class Invoice(models.Model):
     def overdue_days(self):
         return (now().date() - self.date_due).days
 
+    @property
+    def days_to_overdue(self):
+        return (self.date_due - now().date()).days
+
     @property
     def payment_term(self):
         return (self.date_due - self.date_issue).days if self.total > 0 else 0
@@ -392,7 +398,16 @@ class Invoice(models.Model):
     @cached_property
     def max_quantity(self):
         quantity = self.item_set.aggregate(Max('quantity'))
-        return quantity.get('quantity__max', 1) if quantity else 1
+        return quantity.get('quantity__max', 1) if quantity else 0
+
+    @cached_property
+    def sum_quantity(self):
+        quantity = self.item_set.aggregate(Sum('quantity'))
+        return quantity.get('quantity__sum', 1) if quantity else 0
+
+    @cached_property
+    def all_items_with_single_quantity(self):
+        return self.item_set.count() == self.sum_quantity
 
     @property
     def subtotal(self):
